@@ -15,13 +15,14 @@ def shape_data(data):
 
     return data 
 
-def preprocess(data, params):
-    im = np.copy(data)
+def preprocess(im, params):
     im = (1.0 - normalize2max(im)) if params['invert'] else im
-    im = adjust_gamma(im,params['gamma'])
-    im = unsharp_mask(im,2,params['sharpness'])
+
+    im = im if params['scale']==1 else rescale(im,params['scale'],preserve_range=True)
+    
+    im = unsharp_mask(im,params['sharpness_sigma'],params['sharpness_amount']) if params['sharpness_sigma'] > 0 else im
+    im = im if params['gamma'] == 1 else adjust_gamma(im,params['gamma'])
     if params['gaussian_laplace']:
         im = gaussian(laplace(im),2)
-    im = im if params['scale']==1 else rescale(im,params['scale'],preserve_range=True)
     im = add_noise(im,params['sensitivity']) if params['local_noise'] else random_noise(im,mode = 'gaussian',var = params['sensitivity']/100.0)
     return im
\ No newline at end of file
